@@ -1,5 +1,5 @@
 from . import *
-import coloredlogs
+import coloredlogs #type: ignore
 # default colored logs level.
 # You may override it by doing the same thing with 'DEBUG' after importing deeplabel once
-coloredlogs.install('INFO')
\ No newline at end of file
+coloredlogs.install('INFO') #type: ignore
\ No newline at end of file
