@@ -1,7 +1,7 @@
 from logging import getLogger
 
 import deeplabel.client
-from deeplabel.exceptions import InvalidCredentials
+from deeplabel.exceptions import InvalidCredentials, InvalidIdError
 import deeplabel.basemodel
 from pydantic import BaseModel
 from typing import Optional
@@ -27,11 +27,21 @@ class User(deeplabel.basemodel.DeeplabelBase):
 
     @classmethod
     def from_login(cls, email: str, password: str, client: "deeplabel.client.BaseClient")->"User": #type: ignore
-        res = client.session.post(
-            client.label_url + "/users/login",
+        res = client.post(
+            "/users/login",
             json={"email": email, "password": password},
             headers={"Content-Type": "application/json"},
         )
         if res.status_code > 200:
             raise InvalidCredentials(res.text)
         return cls(**res.json()['data'])
+    
+    @classmethod
+    def from_user_id(cls, user_id:str, client: "deeplabel.client.BaseClient") -> "User":
+        res = client.get(
+            "/users",
+            {"userId": user_id},
+        )
+        if res.status_code > 200:
+            raise InvalidIdError(res.text)
+        return cls(**res.json()['data']['users'][0])
