@@ -43,13 +43,13 @@ class BaseClient:
     def headers(self) -> Dict[str, str]:
         return {"Authorization": f"Bearer {self.token}"}  # type: ignore
 
-    def post(self, url: str, json: Dict[str, Any]):
+    def post(self, url: str, json: Dict[str, Any], headers:Optional[Dict[str, str]]=None):
         if not url.startswith("http"):
             url = self._get_url_by_caller(url)
         if self.restriction in ["false",False]:
             json["restriction"] = "false"
         response = self.session.post(
-            url, json=json, headers=self.headers)
+            url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         if response.status_code > 300:
             logger.error(f"{response.status_code}  {url} failed. {response.text} ; data:{json}")
             raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
@@ -72,6 +72,8 @@ class BaseClient:
             return self.infer_url + suffix
         elif "/label/" in caller_filename:
             return self.label_url + suffix
+        elif "/auth/" in caller_filename:
+            return self.label_url + suffix
         else:
             called_func = inspect.stack()[1][3]  #  BaseClient.{get/put/post}
             logger.error(
@@ -87,6 +89,7 @@ class BaseClient:
         url: str,
         params: Dict[str, Any],
         add_project_id: bool = False,
+        headers: Optional[Dict[str,str]] = None
     ):
         """Get a deeplabel get api
 
@@ -110,19 +113,19 @@ class BaseClient:
             url = self._get_url_by_caller(url)
         logger.debug(f"Fetching {url} params: {params}")
         response = self.session.get(
-            url, params=params, headers=self.headers)
+            url, params=params, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         logger.debug(f"Received Response {response.json()}")
         if response.status_code > 202:
             logger.error(f"{response.status_code}  {url} failed. {response.text}")
             raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
         return response
 
-    def put(self, url: str, json: Dict[str, Any]):
+    def put(self, url: str, json: Dict[str, Any], headers:Optional[Dict[str,str]]=None):
         if not url.startswith("http"):
             url = self._get_url_by_caller(url)
         if self.restriction in ["false",False]:
             json["restriction"] = "false"
-        response = self.session.put(url, json=json, headers=self.headers)
+        response = self.session.put(url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
         if response.status_code > 202:
             logger.error(f"{response.status_code}  {url} failed. {response.text}")
             raise InvalidAPIResponse(f"{response.status_code}  {url} {response.text}")
