@@ -13,9 +13,9 @@ from deeplabel.types.polygon import Polygon
 
 
 class DetectionType(Enum):
-    BOUNDING_BOX='IMAGES_BOUNDING_BOX'
-    POLYGON='IMAGES_POLYGON'
-    CLASSIFICATION='IMAGES_CLASSIFICATION'
+    BOUNDING_BOX='IMAGE_BOUNDING_BOX'
+    POLYGON='IMAGE_POLYGON'
+    CLASSIFICATION='IMAGE_CLASSIFICATION'
 
 
 class Detection(DeeplabelBase):
@@ -32,7 +32,7 @@ class Detection(DeeplabelBase):
     sub_class: List[str] = Field(default_factory=list)
 
     @classmethod
-    def _from_search_params(cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient") -> List["Detection"]:  # type: ignore
+    def from_search_params(cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient") -> List["Detection"]:  # type: ignore
         """Make a get request for detections using the passed params. This
         is a private method used internally by other class methods
 
@@ -59,7 +59,7 @@ class Detection(DeeplabelBase):
         Returns:
             Detection: returns a Detection object or raises InvalidIdError if not found
         """
-        detections = cls._from_search_params({"detectionId": detection_id}, client)
+        detections = cls.from_search_params({"detectionId": detection_id}, client)
         if not len(detections):
             raise InvalidIdError(
                 f"Failed to fetch detections with detectionId  : {detection_id}"
@@ -76,7 +76,7 @@ class Detection(DeeplabelBase):
         Returns:
             List[Detection]: List of detections for the given galleryTaskId
         """
-        return cls._from_search_params({"galleryTaskId": gallery_task_id}, client)
+        return cls.from_search_params({"galleryTaskId": gallery_task_id}, client)
 
     # Below is the update method implemented by Sivaram, and then commented out by him.
     # Leaving it here as a reminder that the Detection.update is not needed to be in sdk
