@@ -15,6 +15,7 @@ import yarl
 import os
 from deeplabel.exceptions import DeeplabelValueError
 from logging import getLogger
+
 logger = getLogger(__name__)
 
 
@@ -88,7 +89,9 @@ class Video(DeeplabelBase):
     project_id: str
     input_url: str
     video_urls: Optional[_VideoUrl]
-    video_url: Optional[str]  # videoUrls.source.url if exists else videoUrl is used for legacy support. In case both are absent, use input_url
+    # videoUrls.source.url if exists else videoUrl is used for legacy support.
+    # In case both are absent, use input_url
+    video_url: Optional[str]
     thumbnail_url: Optional[str]
     status: _LabelVideoStatus
     extraction_points: List[ExtractionPoint]
@@ -104,7 +107,7 @@ class Video(DeeplabelBase):
         project_id: str,
         client: "deeplabel.client.BaseClient",
         parent_folder_id: Optional[str] = None,
-        is_feedback:bool = False
+        is_feedback: bool = False,
     ) -> str:
         """Create a video and return the video"""
         resp = client.post(
@@ -113,7 +116,7 @@ class Video(DeeplabelBase):
                 "inputUrl": input_url,
                 "projectId": project_id,
                 "parentFolderId": parent_folder_id,
-                "isFeedback": is_feedback
+                "isFeedback": is_feedback,
             },
         )
         video_id = resp.json()["data"]["videoId"]
@@ -165,7 +168,7 @@ class Video(DeeplabelBase):
     @property
     def ext(self):
         """Extenion of the video, deduced from path/name"""
-        return os.path.splitext(yarl.URL(self.video_url).name)[-1] #type: ignore
+        return os.path.splitext(yarl.URL(self.video_url).name)[-1]  # type: ignore
 
     @property
     def detections(self):
@@ -218,7 +221,7 @@ class Video(DeeplabelBase):
                 "extractionPoints": [
                     point.dict(by_alias=True, exclude_none=True)
                     for point in extraction_timepoints
-                    ]
+                ],
             },  # type: ignore
         )
         if resp.status_code > 400:
@@ -231,6 +234,7 @@ class Video(DeeplabelBase):
         detections: List["deeplabel.label.videos.detections.Detection"],
         chunk_size: int = 500,
     ):
+        DetectionType = deeplabel.label.videos.detections.DetectionType
         label_task = self.get_task_by_name("LABEL")
         if (
             label_task is None
@@ -244,15 +248,25 @@ class Video(DeeplabelBase):
 
         i = 0
         while i * chunk_size < len(detections):
-            resp = self.client.put(
-                "/projects/videos/frames/detections",
-                {"batch": "true",
-                "data": [
-                    detection.dict(by_alias=True, exclude_none=True)
-                    for detection in detections[chunk_size * i : chunk_size * (i + 1)]
-                    ],
+            request_detections:List[Dict[str, Any]] = []
+            for detection in detections[chunk_size * i : chunk_size * (i + 1)]:
+                det = {
+                    "labelId": detection.label_id.label_id,
+                    "type": detection.type.value,
+                    "frameId": detection.frame_id
                 }
-            )
+                if detection.type == DetectionType.BOUNDING_BOX:
+                    det["boundingBox"] = detection.bounding_box.dict( #type: ignore
+                        exclude_defaults=True, exclude_none=True
+                    )
+                if detection.type == DetectionType.POLYGON:
+                    det["polygon"] = detection.polygon.dict()  # type: ignore
+                request_detections.append(det)
+            request_data = {
+                "batch": True,
+                "data": request_detections,
+            }
+            resp = self.client.post("/projects/videos/frames/detections", request_data)
             if resp.status_code > 400:
                 raise DeeplabelValueError(
                     f"Failed inserting detections for videoId {self.video_id} with IN_PROGRESS LABEL task {label_task.video_task_id}: {resp.json()}"
